/*
 * gabble.h — API for telepathy-gabble plugins
 * Copyright © 2010 Collabora Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef GABBLE_PLUGINS_GABBLE_H
#define GABBLE_PLUGINS_GABBLE_H

#define IN_GABBLE_PLUGINS_GABBLE_H

#include <glib-object.h>

#include <gabble/capabilities.h>
#include <gabble/capabilities-set.h>
#include <gabble/caps-channel-manager.h>
#include <gabble/caps-hash.h>
#include <gabble/plugin-connection.h>
#include <gabble/error.h>
#include <gabble/namespaces.h>
#include <gabble/plugin.h>
#include <gabble/sidecar.h>
#include <gabble/types.h>

#undef IN_GABBLE_PLUGINS_GABBLE_H

#endif
